/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.objectweb.petals.tools.rmi.serializable;

import java.io.Serializable;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;

/**
 * The MBeanNames implementation for RMI component.
 * @author Nicolas Salatge - EBM WebSourcing
 */
public class MBeanNamesImpl implements javax.jbi.management.MBeanNames, Serializable {

    /**
     * the serialVersionUID.
     */
    private static final long serialVersionUID = -1832201538669181132L;

    /**
     * Custom name.
     */
    private static final String CUSTOM = "custom";

    /**
     * the domain.
     */
    private String domain;

    /**
     * Constructs the MBeanNames with the specified domain name. This domain
     * name will be used for creating mBean names.
     *
     * @param domain
     *            the domain
     */
    public MBeanNamesImpl(final String domain) {
        this.domain = domain;
    }

    /**
     * @see javax.jbi.management.MBeanNames#createCustomComponentMBeanName(String
     *      customName)
     * @param customName
     *          the customName
     * @return
     *        the object name
     */
    public ObjectName createCustomComponentMBeanName(final String customName) {
        String type = MBeanNamesImpl.CUSTOM;
        String theType = null;
        if (type != null) {
            type =  "type=" + type + ",";
        } else {
            type = "";
        }
        String theName = "name=" + customName;
        ObjectName on = null;
        try {
            on = new ObjectName(this.domain + ":" + theType + theName);
        } catch (MalformedObjectNameException e) {
            throw new RuntimeException(e);
            // internal use, so exeception should never be thrown
        }
        return on;
    }

    /**
     * @see javax.jbi.management.MBeanNames#getJmxDomainName()
     * @return
     *     the domain
     */
    public String getJmxDomainName() {
        return this.domain;
    }
}


